package at.ac.uibk.gitsearch.repository.jpa;

import at.ac.uibk.gitsearch.domain.Statistics;
import java.util.List;
import java.util.Optional;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

/**
 * Spring Data  repository for the Statistics entity.
 */
@Repository
@SuppressWarnings("PMD.AvoidDuplicateLiterals")
public interface StatisticsRepository extends JpaRepository<Statistics, Long> {
    Optional<Statistics> findByExerciseID(String id);

    @Override
    Optional<Statistics> findById(Long id);

    @Query("SELECT SUM(u.views) FROM Statistics u WHERE u.exerciseID IN (:ids)")
    Optional<Integer> findNumberOfViewsByExerciseIDs(@Param("ids") List<String> exerciseIds);

    @Query("SELECT SUM(u.downloads) FROM Statistics u WHERE u.exerciseID IN (:ids)")
    Optional<Integer> findNumberOfDownloadsByExerciseIDs(@Param("ids") List<String> exerciseIds);

    @Query("SELECT SUM(u.downloads), SUM(u.views) FROM Statistics u WHERE u.exerciseID IN (:ids)")
    List<Integer[]> findNumberOfDownloadsAndViewsByExerciseIDs(@Param("ids") List<String> exerciseIds);

    @Query("SELECT COUNT(u.exerciseId) FROM WatchListEntry u where exerciseId = :id")
    Integer findNumberOfWatchListEntriesByExerciseID(@Param("id") String exerciseID);

    @Query("SELECT s FROM Statistics s WHERE s.exerciseID in (:ids)")
    List<Statistics> findStatisticsByExerciseIds(@Param("ids") List<String> exerciseIds);

    @Query("SELECT SUM(u.downloads), SUM(u.views) FROM Statistics u")
    List<Integer[]> findNumberOfDownloadsAndViews();
}
