package at.ac.uibk.gitsearch.service.criteria;

import java.io.Serializable;
import java.util.Objects;
import tech.jhipster.service.Criteria;
import tech.jhipster.service.filter.Filter;
import tech.jhipster.service.filter.LongFilter;
import tech.jhipster.service.filter.StringFilter;

/**
 * Criteria class for the {@link at.ac.uibk.gitsearch.domain.Review} entity. This class is used
 * in {@link at.ac.uibk.gitsearch.web.rest.ReviewResource} to receive all the possible filtering options from
 * the Http GET request parameters.
 * For example the following could be a valid request:
 * {@code /reviews?id.greaterThan=5&attr1.contains=something&attr2.specified=false}
 * As Spring is unable to properly convert the types, unless specific {@link Filter} class are used, we need to use
 * fix type specific filters.
 */
@SuppressWarnings(
    {
        "PMD.GodClass",
        "PMD.TooManyMethods",
        "PMD.AvoidFieldNameMatchingMethodName",
        "PMD.ShortMethodName",
        "PMD.NPathComplexity",
        "PMD.ConfusingTernary",
    }
)
public class ReviewCriteria implements Serializable, Criteria {

    private static final long serialVersionUID = 1L;

    private LongFilter id;

    private StringFilter link;

    private LongFilter requestedBy;

    private StringFilter resource;

    private StringFilter resourceID;

    private LongFilter commentsId;

    private LongFilter historyId;

    private Boolean distinct;

    public ReviewCriteria() {}

    public ReviewCriteria(ReviewCriteria other) {
        this.id = other.id == null ? null : other.id.copy();
        this.link = other.link == null ? null : other.link.copy();
        this.requestedBy = other.requestedBy == null ? null : other.requestedBy.copy();
        this.resource = other.resource == null ? null : other.resource.copy();
        this.resourceID = other.resourceID == null ? null : other.resourceID.copy();
        this.commentsId = other.commentsId == null ? null : other.commentsId.copy();
        this.historyId = other.historyId == null ? null : other.historyId.copy();
        this.distinct = other.distinct;
    }

    @Override
    public ReviewCriteria copy() {
        return new ReviewCriteria(this);
    }

    public LongFilter getId() {
        return id;
    }

    public LongFilter id() {
        if (id == null) {
            id = new LongFilter();
        }
        return id;
    }

    public void setId(LongFilter id) {
        this.id = id;
    }

    public StringFilter getLink() {
        return link;
    }

    public StringFilter link() {
        if (link == null) {
            link = new StringFilter();
        }
        return link;
    }

    public void setLink(StringFilter link) {
        this.link = link;
    }

    public LongFilter getRequestedBy() {
        return requestedBy;
    }

    public LongFilter requestedBy() {
        if (requestedBy == null) {
            requestedBy = new LongFilter();
        }
        return requestedBy;
    }

    public void setRequestedBy(LongFilter requestedBy) {
        this.requestedBy = requestedBy;
    }

    public StringFilter getResource() {
        return resource;
    }

    public StringFilter resource() {
        if (resource == null) {
            resource = new StringFilter();
        }
        return resource;
    }

    public void setResource(StringFilter resource) {
        this.resource = resource;
    }

    public StringFilter getResourceID() {
        return resourceID;
    }

    public StringFilter resourceID() {
        if (resourceID == null) {
            resourceID = new StringFilter();
        }
        return resourceID;
    }

    public void setResourceID(StringFilter resourceID) {
        this.resourceID = resourceID;
    }

    public LongFilter getCommentsId() {
        return commentsId;
    }

    public LongFilter commentsId() {
        if (commentsId == null) {
            commentsId = new LongFilter();
        }
        return commentsId;
    }

    public void setCommentsId(LongFilter commentsId) {
        this.commentsId = commentsId;
    }

    public LongFilter getHistoryId() {
        return historyId;
    }

    public LongFilter historyId() {
        if (historyId == null) {
            historyId = new LongFilter();
        }
        return historyId;
    }

    public void setHistoryId(LongFilter historyId) {
        this.historyId = historyId;
    }

    public Boolean getDistinct() {
        return distinct;
    }

    public void setDistinct(Boolean distinct) {
        this.distinct = distinct;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        final ReviewCriteria that = (ReviewCriteria) o;
        return (
            Objects.equals(id, that.id) &&
            Objects.equals(link, that.link) &&
            Objects.equals(requestedBy, that.requestedBy) &&
            Objects.equals(resource, that.resource) &&
            Objects.equals(resourceID, that.resourceID) &&
            Objects.equals(commentsId, that.commentsId) &&
            Objects.equals(historyId, that.historyId) &&
            Objects.equals(distinct, that.distinct)
        );
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, link, requestedBy, resource, resourceID, commentsId, historyId, distinct);
    }

    // prettier-ignore
    @Override
    public String toString() {
        return "ReviewCriteria{" +
            (id != null ? "id=" + id + ", " : "") +
            (link != null ? "link=" + link + ", " : "") +
            (requestedBy != null ? "requestedBy=" + requestedBy + ", " : "") +
            (resource != null ? "resource=" + resource + ", " : "") +
            (resourceID != null ? "resourceID=" + resourceID + ", " : "") +
            (commentsId != null ? "commentsId=" + commentsId + ", " : "") +
            (historyId != null ? "historyId=" + historyId + ", " : "") +
            (distinct != null ? "distinct=" + distinct + ", " : "") +
            "}";
    }
}
