import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { FormBuilder, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';

import { ILikes, Likes } from 'app/shared/model/likes.model';
import { LikesService } from './likes.service';

@Component({
  selector: 'jhi-likes-update',
  templateUrl: './likes-update.component.html',
})
export class LikesUpdateComponent implements OnInit {
  isSaving = false;
  dateDp: any;

  editForm = this.fb.group({
    id: [],
    date: [null, [Validators.required]],
    userID: [null, [Validators.required]],
    exerciseID: [null, [Validators.required]],
  });

  constructor(protected likesService: LikesService, protected activatedRoute: ActivatedRoute, private fb: FormBuilder) {}

  ngOnInit(): void {
    this.activatedRoute.data.subscribe(({ likes }) => {
      this.updateForm(likes);
    });
  }

  updateForm(likes: ILikes): void {
    this.editForm.patchValue({
      id: likes.id,
      date: likes.date,
      userID: likes.userID,
      exerciseID: likes.exerciseID,
    });
  }

  previousState(): void {
    window.history.back();
  }

  save(): void {
    this.isSaving = true;
    const likes = this.createFromForm();
    if (likes.id !== undefined) {
      this.subscribeToSaveResponse(this.likesService.update(likes));
    } else {
      this.subscribeToSaveResponse(this.likesService.create(likes));
    }
  }

  private createFromForm(): ILikes {
    return {
      ...new Likes(),
      id: this.editForm.get(['id'])!.value,
      date: this.editForm.get(['date'])!.value,
      userID: this.editForm.get(['userID'])!.value,
      exerciseID: this.editForm.get(['exerciseID'])!.value,
    };
  }

  protected subscribeToSaveResponse(result: Observable<HttpResponse<ILikes>>): void {
    result.subscribe({
      next: () => this.onSaveSuccess(),
      error: () => this.onSaveError(),
    });
  }

  protected onSaveSuccess(): void {
    this.isSaving = false;
    this.previousState();
  }

  protected onSaveError(): void {
    this.isSaving = false;
  }
}
