import { Injectable } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { Resolve, ActivatedRouteSnapshot, Routes, Router } from '@angular/router';
import { Observable, of, EMPTY } from 'rxjs';
import { mergeMap } from 'rxjs/operators';

import { Authority } from 'app/app.constants';
import { UserRouteAccessService } from 'app/core/auth/user-route-access.service';
import { IUserWatchList, UserWatchList } from 'app/shared/model/user-watch-list.model';
import { UserWatchListService } from './user-watch-list.service';
import { UserWatchListComponent } from './user-watch-list.component';
import { UserWatchListDetailComponent } from './user-watch-list-detail.component';
import { UserWatchListUpdateComponent } from './user-watch-list-update.component';

@Injectable({ providedIn: 'root' })
export class UserWatchListResolve implements Resolve<IUserWatchList> {
  constructor(private service: UserWatchListService, private router: Router) {}

  resolve(route: ActivatedRouteSnapshot): Observable<IUserWatchList> | Observable<never> {
    const id = route.params['id'];
    if (id) {
      return this.service.find(id).pipe(
        mergeMap((userWatchList: HttpResponse<UserWatchList>) => {
          if (userWatchList.body) {
            return of(userWatchList.body);
          } else {
            this.router.navigate(['404']);
            return EMPTY;
          }
        })
      );
    }
    return of(new UserWatchList());
  }
}

export const userWatchListRoute: Routes = [
  {
    path: '',
    component: UserWatchListComponent,
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.userWatchList.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
  {
    path: ':id/view',
    component: UserWatchListDetailComponent,
    resolve: {
      userWatchList: UserWatchListResolve,
    },
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.userWatchList.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
  {
    path: 'new',
    component: UserWatchListUpdateComponent,
    resolve: {
      userWatchList: UserWatchListResolve,
    },
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.userWatchList.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
  {
    path: ':id/edit',
    component: UserWatchListUpdateComponent,
    resolve: {
      userWatchList: UserWatchListResolve,
    },
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.userWatchList.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
];
